<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2013, Unixvers
 * The GPL License.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Oxwall Foundation nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

class GCONNECT_CTRL_Admin extends ADMIN_CTRL_Abstract
{
	public function __construct() {
        parent::__construct();
    }
	public function index(){	

		$form = new GCONNECT_AccessForm();
		$this->addForm($form);
	

		if ( OW::getRequest()->isPost() && $form->isValid($_POST) ){
	
			if ( $form->process() ){
				OW::getFeedback()->info(OW::getLanguage()->text('GConnect', 'register_app_success'));
				$this->redirect(OW::getRouter()->urlForRoute('gconnect_app_success_page'));
			}
		
            OW::getFeedback()->error(OW::getLanguage()->text('GConnect', 'register_app_failed'));	
			$this->redirect();
		}  
		$this->assign('returnUrl',OW::getRouter()->urlForRoute('gconnect_oauth'));
		OW::getDocument()->setHeading(OW::getLanguage()->text('GConnect', 'heading_configuration'));
        OW::getDocument()->setHeadingIconClass('ow_ic_friends');
	}
	
	public function success() {
		OW::getDocument()->setHeading(OW::getLanguage()->text('GConnect', 'heading_configuration'));
		$success_text = OW::getLanguage()->text('GConnect','register_success_msg');
		$this->assign('text', $success_text);
	}
    
}



class GCONNECT_SettingsForm extends Form
{

    public function __construct()
    {
        parent::__construct('GCONNECT_SettingsForm');

        $config = OW::getConfig();

        $field = new CheckboxField('allowSynchronize');
        $field->setValue((bool) $config->getValue('gconnect', 'allow_synchronize'));
        $this->addElement($field);

        // submit
        $submit = new Submit('save');
        $submit->setValue(OW::getLanguage()->text('gconnect', 'save_btn_label'));
        $this->addElement($submit);
    }

    public function process()
    {
        $values = $this->getValues();
        $config = OW::getConfig();

        $config->saveConfig('gconnect', 'allow_synchronize', $values['allowSynchronize']);

        return array('result' => true);
    }
}

class GCONNECT_AccessForm extends Form {
	
	public function __construct()
    {
        parent::__construct('GCONNECT_AccessForm');
        $config = OW::getConfig();
		
		$field = new TextField('clientId');
        $field->setRequired(true);
	    $field->setValue($config->getValue('gconnect', 'client_id'));
		$this->addElement($field);
        
		$field = new TextField('clientSecret');
		$field->setRequired(true);
		$field->setValue($config->getValue('gconnect', 'client_secret'));
		$this->addElement($field);
		
		$submit = new Submit('save');
        $submit->setValue(OW::getLanguage()->text('GConnect', 'save_btn_label'));
		$this->addElement($submit);
	}
	
	public function process(){
       
		$values = $this->getValues();
		
        $config = OW::getConfig();

        $apiId = trim($values['clientId']);
        $apiSecret = trim($values['clientSecret']);

        $config->saveConfig('gconnect', 'client_id', $apiId);
        $config->saveConfig('gconnect', 'client_secret', $apiSecret);

        return GCONNECT_BOL_AdminService::getInstance()->configureApplication();
    }
	
}