<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2013, Unixvers
 * The GPL License.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Oxwall Foundation nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

class GCONNECT_CTRL_Connect extends OW_ActionController
{
    /**
     *
     * @var GCONNECT_BOL_Service
     */
    private $service;

    public function init()
    {
        $this->service = GCONNECT_BOL_Service::getInstance();
    }

	public function oauth(){
		$authurl = OW::getRouter()->getBaseUrl().OW::getRouter()->uriForRoute('gconnect_login');
		$this->assign('authurl', $authurl);
	}
	
	public function login( $params )
    {
		 $backUri = empty($_GET['backUri']) ? '' : urldecode($_GET['backUri']);
         $backUrl = OW_URL_HOME . $backUri;
         $language = OW::getLanguage();
		 $user = $this->service->gRequireUser();
		 if ( !$user) {
			
			 $this->redirect(OW::getRouter()->getBaseUrl());
		 }else {
			 // Register or login 
			 $datalogin = $user->author;
			 $datalogin = get_object_vars($datalogin);
			 $name = explode(' ',$datalogin['name']);
			 $count = 0;$nome = ''; $cognome = '';
			 foreach ( $name as $userval ){
				 if (!$count) { $nome = $userval;$count++; continue; }
				 $cognome .= $userval.' ';
				 $count++;
			 }
	         $authAdapter = new GCONNECT_CLASS_AuthAdapter($datalogin['email']);
			 if ( $authAdapter->isRegistered() ) {
				 // LOGIN
				
				 $authResult = OW::getUser()->authenticate($authAdapter);
				if ( $authResult->isValid() ){
				    OW::getFeedback()->info($language->text('GConnect', 'login_success_msg'));
			    }
			    else{
					OW::getFeedback()->error($language->text('GCconnect', 'login_failure_msg'));
				 }
				 
  	             $this->redirect(OW::getRouter()->urlForRoute('base_member_profile'));
			 }else{
				 //REGISTER
				
				 $username = strtolower(str_replace(' ','',$nome.$cognome.uniqid()));
				 $username = preg_replace('/[^A-Za-z0-9_]/', '', $username);
				
				 $password = uniqid();
				 try{
				    $user = BOL_UserService::getInstance()->createUser($username, $password, $datalogin['email'], null, true);
				 } catch ( Exception $e ) {
					switch ( $e->getCode() ){
					    case BOL_UserService::CREATE_USER_DUPLICATE_EMAIL:
							
							$searcher = BOL_UserService::getInstance()->findByEmail($datalogin['email']);
							if ( strlen($searcher->id) > 0 ) {
								OW::getUser()->login($searcher->id);
								$this->redirect(OW::getRouter()->urlForRoute('base_member_profile'));
							}
							OW::getFeedback()->error($language->text('GConnect', 'join_dublicate_email_msg'));
							$this->redirect(OW::getRouter()->getBaseUrl());
						break;
			            case BOL_UserService::CREATE_USER_INVALID_USERNAME:
				            OW::getFeedback()->error($language->text('GConnect', 'join_incorrect_username'));
						    $this->redirect(OW::getRouter()->getBaseUrl());
						break;
		                default:
				            OW::getFeedback()->error($language->text('GConnect', 'join_incomplete'));
						    $this->redirect(OW::getRouter()->getBaseUrl());
					}
				} //END TRY-CATCH
		        BOL_QuestionService::getInstance()->saveQuestionsData(array('realname' => $nome.' '.$cognome), $user->id);
				
				$authAdapter->register($user->id);
				
		        $authResult = OW_Auth::getInstance()->authenticate($authAdapter);
				if ( $authResult->isValid() ){
				    $event = new OW_Event(OW_EventManager::ON_USER_REGISTER, array('method' => 'google', 'userId' => $user->id));
					OW::getEventManager()->trigger($event);
					OW::getFeedback()->info($language->text('GConnect', 'join_success_msg'));
				} else {
					OW::getFeedback()->error($language->text('GConnect', 'join_failure_msg'));
				}
				
  	             $this->redirect(OW::getRouter()->urlForRoute('base_edit'));
			}

		 }
	}
	
	public function synchronize()
    {
        $backUri = empty($_GET['backUri']) ? '' : urldecode($_GET['backUri']);
        $backUrl = OW_URL_HOME . $backUri;

        $language = OW::getLanguage();

        $userId = OW::getUser()->getId();

        if ( empty($userId) )
        {
            throw new AuthenticateException();
        }

        $gUser = $this->service->gRequireUser();

        $questionsService = BOL_QuestionService::getInstance();
        $userService = BOL_UserService::getInstance();

        $accountType = $userService->findUserById($userId)->getAccountType();
        $editQuestionsDtoList = $questionsService->findEditQuestionsForAccountType($accountType);

        $editQuestions = array();
        foreach ( $editQuestionsDtoList as $item )
        {
            $editQuestions[] = $item['name'];
        }

        $questions = $this->service->requestQuestionValueList($gUser, $editQuestions, $userId);

        if ( !empty($questions['email']) && $userService->isExistEmail($questions['email']) )
        {
            unset($questions['email']);
        }

        $questionsService->saveQuestionsData(array_filter($questions), $userId);

        OW::getFeedback()->info(OW::getLanguage()->text('gconnect', 'synchronize_success_msg'));
        $event = new OW_Event(OW_EventManager::ON_USER_EDIT, array('method' => 'google', 'userId' => $userId));
        OW::getEventManager()->trigger($event);

        $this->redirect($backUrl);
    }

	
}