<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2013, Unixvers
 * The GPL License.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Oxwall Foundation nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

$plugin = OW::getPluginManager()->getPlugin('gconnect');

function GCONNECT_Autoloader( $className )
{
    if ( strpos($className, 'GCONNECT_FC_') === 0 )
    {
        $file = OW::getPluginManager()->getPlugin('gconnect')->getRootDir() . DS . 'classes' . DS . 'converters.php';
        require_once $file;

        return true;
    }
}

spl_autoload_register('GCONNECT_Autoloader');

//Route che punta al login : gconnect_login
OW::getRouter()->addRoute(new OW_Route('gconnect_login', 'google-connect/login', 'GCONNECT_CTRL_Connect', 'login'));
OW::getRouter()->addRoute(new OW_Route('gconnect_oauth', 'google-connect/oatuh', 'GCONNECT_CTRL_Connect', 'oauth'));


//Route che punta alla prima maschera di configurazione
OW::getRouter()->addRoute(new OW_Route('gconnect_admin_main','admin/plugins/gconnect','GCONNECT_CTRL_Admin', 'index'));
OW::getRouter()->addRoute(new OW_Route('gconnect_app_success_page','admin/plugins/gconnect','GCONNECT_CRTL_Admin', 'success'));

$configs = OW::getConfig()->getValues('gconnect');
if ( !empty($configs['client_id']) && !empty($configs['client_secret']) ) {
	$registry = OW::getRegistry();
	$registry->addToArray(BASE_CTRL_Join::JOIN_CONNECT_HOOK, array(new GCONNECT_CMP_ConnectButton(), 'render'));
	$registry->addToArray(BASE_CTRL_Edit::EDIT_SYNCHRONIZE_HOOK, array(new GCONNECT_CMP_SynchronizeButton(), 'render'));
	$registry->addToArray(BASE_CMP_ConnectButtonList::HOOK_REMOTE_AUTH_BUTTON_LIST, array(new GCONNECT_CMP_ConnectButton(), 'render'));
		
}

OW::getEventManager()->bind(BASE_CMP_ConnectButtonList::HOOK_REMOTE_AUTH_BUTTON_LIST, 'gconnect_event_add_button');

function gconnect_event_add_button( BASE_CLASS_EventCollector $event )
{
    $cssUrl = OW::getPluginManager()->getPlugin('GCONNECT')->getStaticCssUrl() . 'gconnect.css';
    OW::getDocument()->addStyleSheet($cssUrl);

    $button = new GCONNECT_CMP_ConnectButton();
    $event->add(array('iconClass' => 'ow_ico_signin_g', 'markup' => $button->render()));
}

//Funzione per notificare che si necessita la configurazione del plugin

function gconnect_add_admin_notification( BASE_CLASS_EventCollector $e )
 {
    $language = OW::getLanguage();
    $configs = OW::getConfig()->getValues('gconnect');
    if ( empty($configs['client_id']) || empty($configs['client_secret']) )
    {
        $e->add($language->text('GConnect', 'admin_configuration_required_notification', array( 'href' => OW::getRouter()->urlForRoute('gconnect_admin_main') )));
    }
 }
 //Bindo l'evento della notifica nell'admin
 OW::getEventManager()->bind('admin.add_admin_notification', 'gconnect_add_admin_notification');
 
function gconnect_add_access_exception( BASE_CLASS_EventCollector $e ) {
	$e->add(array('controller' => 'GCONNECT_CTRL_Connect', 'action' => 'login'));
	$e->add(array('controller' => 'GCONNECT_CTRL_Connect', 'action' => 'oauth'));

}

OW::getEventManager()->bind('base.members_only_exceptions', 'gconnect_add_access_exception');
OW::getEventManager()->bind('base.password_protected_exceptions', 'gconnect_add_access_exception');
OW::getEventManager()->bind('base.splash_screen_exceptions', 'gconnect_add_access_exception');

function gconnect_event_on_user_synchronized( OW_Event $event )
{
    $params = $event->getParams();

    if ( !OW::getPluginManager()->isPluginActive('activity') || $params['method'] !== 'google' )
    {
        return;
    }
    $event = new OW_Event(OW_EventManager::ON_USER_EDIT, array('method' => 'native', 'userId' => $params['userId']));
    OW::getEventManager()->trigger($event);
}
OW::getEventManager()->bind(OW_EventManager::ON_USER_EDIT, 'gconnect_event_on_user_synchronized');

//Notifico nella tua feedback che ti sei loggato con google 
function gconnect_event_on_user_registered( OW_Event $event )
{
    $params = $event->getParams();

    if ( $params['method'] != 'google' )
    {
        return;
    }

    $userId = (int) $params['userId'];

    $event = new OW_Event('feed.action', array(
        'pluginKey' => 'base',
        'entityType' => 'user_join',
        'entityId' => $userId,
        'userId' => $userId,
        'replace' => true,
    ), array(
        'string' => OW::getLanguage()->text('GConnect', 'feed_user_join'),
        'view' => array(
            'iconClass' => 'ow_ic_user'
        )
    ));
    OW::getEventManager()->trigger($event);
}
OW::getEventManager()->bind(OW_EventManager::ON_USER_REGISTER, 'gconnect_event_on_user_registered');
